---
name: Feature Request
about: Feel like something is mising? Let us know!
title: ''
labels: 'enhancement'
assignees: ''
---

**Describe the Feature**
A clear and concise description of what the what you want to be added.

**Why is the feature important for you?**
Share code to reproduce the issue

**Additional context**
Add any other context about the feature you want to share with us.

<!-- PS: Thanks for your valuable feedback. Really! Its feedback from valuable community members like you that help us make Ragas event better for the whole community. So thanks again for taking the time to improve our community 🙂 -->
